pub struct WlanBaseStationWatcherProxy { /* private fields */ }Implementations
Sourceimpl WlanBaseStationWatcherProxy
impl WlanBaseStationWatcherProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.location.sensor/WlanBaseStationWatcher.
Sourcepub fn take_event_stream(&self) -> WlanBaseStationWatcherEventStream
pub fn take_event_stream(&self) -> WlanBaseStationWatcherEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn report_current_stations(
&self,
stations: ClientEnd<ScanResultIteratorMarker>,
) -> Result<(), Error>
pub fn report_current_stations( &self, stations: ClientEnd<ScanResultIteratorMarker>, ) -> Result<(), Error>
Provides a handle with which to enumerate the stations currently visible to the device.